@@ -1,4 +1,4 @@
-# $Id: Parser.pm 18 2005-08-17 10:20:53Z daisuke $
+# $Id: Parser.pm 20 2005-10-18 09:41:09Z daisuke $
 #
 # Copyright (c) 2005 Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
@@ -261,4 +261,47 @@ sub _parse_children
     return \%item;
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 NAME 
+
+XML::RSS::LibXML::Parser - RSS Parser for XML::RSS::LibXML
+
+=head1 SYNOPSIS
+
+  use XML::RSS::LibXML;
+  use XML::RSS::LibXML::Parser;
+
+  my $rss = XML::RSS::LibXML->new;
+  my $p   = XML::RSS::LiBXML::Parser->new;
+
+  $p->parsefile($rss, $file);
+  $p->parse($rss, $string);
+
+=head1 DESCRIPTION
+
+XML::RSS::LibXML::Parser parses RSS files and appropriately populates the
+data structures in XML::RSS::LibXML
+
+=head1 METHODS
+
+=head2 new
+
+Create a new parser.
+
+=head2 parsefile($rss, $file)
+
+Parses an RSS file $file and populate $rss with its data.
+
+=head2 parse($rss, $string)
+
+Parses an RSS string and populate $rss with its data.
+
+=head1 AUTHOR
+
+Copyright (c) 2005 Daisuke Maki E<lt>dmaki@cpan.orgE<gt>.
+Development partially funded by Brazil, Ltd. E<lt>http://b.razil.jpE<gt>
+
+=cut
\ No newline at end of file
